---
title: Ast Services
author:
date: 2024-03-01
...

# Ast Services {#ast-services}

## kernel.ast.compute (`EXEC`) {#compute}

Ensures that AST is computed


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## kernel.ast.changed (`SIGNAL`) {#changed}

Emitted when the AST has been changed


## kernel.ast.source (`DATA`) {#source}

Source file positions.


> [`source`](#source)  `::=` `{` `"dir"` `:` _string_ , `"base"` `:` _string_
  , `"file"` `:` _string_ , `"line"` `:` _number_ `}`
  

## kernel.ast.fct (`DATA`) {#fct}

Function names


> [`fct`](#fct)  `::=` `$fct`
  

## kernel.ast.marker (`DATA`) {#marker}

Localizable AST markers


> [`marker`](#marker)  `::=` `$marker`
  

## kernel.ast.location (`DATA`) {#location}

Location: function and marker


> [`location`](#location)  `::=` `{` `"fct"` `:` [`fct`](ast.md#fct)  ,
  `"marker"` `:` [`marker`](ast.md#marker)  `}`
  

## kernel.ast.markerAttributes (`ARRAY`) {#markerattributes}

Marker attributes


## kernel.ast.signalMarkerAttributes (`SIGNAL`) {#signalmarkerattributes}

Signal for array [`markerAttributes`](#markerattributes) 


## kernel.ast.markerAttributesData (`DATA`) {#markerattributesdata}

Data for array rows [`markerAttributes`](#markerattributes) 


> [`markerAttributesData`](#markerattributesdata)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"marker"` | [`marker`](ast.md#marker)  | Entry identifier. |
| `"labelKind"` | _string_ | Marker kind (short) |
| `"titleKind"` | _string_ | Marker kind (long) |
| `"name"` | _string_ | Marker short name  or identifier when relevant. |
| `"descr"` | _string_ | Marker declaration or description |
| `"isLval"` | _boolean_ | Whether it is an l-value |
| `"isFunction"` | _boolean_ | Whether it is a function symbol |
| `"isFunctionPointer"` | _boolean_ | Whether it is a function pointer |
| `"isFunDecl"` | _boolean_ | Whether it is a function declaration |
| `"scope"` (opt.) | _string_ | Function scope of the marker, if applicable |
| `"sloc"` (opt.) | [`source`](ast.md#source)  | Source location |


## kernel.ast.fetchMarkerAttributes (`GET`) {#fetchmarkerattributes}

Data fetcher for array [`markerAttributes`](#markerattributes) 


> _input_ `::=` _number_
  

> _output_ `::=` `{` _output…_ `}`
  

| Output | Format | Description |
|:-------|:------:|:------------|
| `"reload"` | _boolean_ | array fully reloaded |
| `"removed"` | [`marker`](ast.md#marker)  `[]` | removed entries |
| `"updated"` | [`markerAttributesData`](ast.md#markerattributesdata)  `[]` | updated entries |
| `"pending"` | _number_ | remaining entries to be fetched |


## kernel.ast.reloadMarkerAttributes (`GET`) {#reloadmarkerattributes}

Force full reload for array [`markerAttributes`](#markerattributes) 


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## kernel.ast.getMainFunction (`GET`) {#getmainfunction}

Get the current 'main' function.


> _input_ `::=` _null_
  

> _output_ `::=` [`fct`](ast.md#fct)  `?`
  

## kernel.ast.getFunctions (`GET`) {#getfunctions}

Collect all functions in the AST


> _input_ `::=` _null_
  

> _output_ `::=` [`fct`](ast.md#fct)  `[]`
  

## kernel.ast.printFunction (`GET`) {#printfunction}

Print the AST of a function


> _input_ `::=` [`fct`](ast.md#fct) 
  

> _output_ `::=` [`text`](data.md#text) 
  

> _signals_
  

* `kernel.ast.changed`


## kernel.ast.functions (`ARRAY`) {#functions}

AST Functions


## kernel.ast.signalFunctions (`SIGNAL`) {#signalfunctions}

Signal for array [`functions`](#functions) 


## kernel.ast.functionsData (`DATA`) {#functionsdata}

Data for array rows [`functions`](#functions) 


> [`functionsData`](#functionsdata)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"key"` | `$functions` | Entry identifier. |
| `"name"` | _string_ | Name |
| `"signature"` | _string_ | Signature |
| `"main"` (opt.) | _boolean_ | Is the function the main entry point |
| `"defined"` (opt.) | _boolean_ | Is the function defined? |
| `"stdlib"` (opt.) | _boolean_ | Is the function from the Frama-C stdlib? |
| `"builtin"` (opt.) | _boolean_ | Is the function a Frama-C builtin? |
| `"extern"` (opt.) | _boolean_ | Is the function extern? |
| `"sloc"` | [`source`](ast.md#source)  | Source location |


## kernel.ast.fetchFunctions (`GET`) {#fetchfunctions}

Data fetcher for array [`functions`](#functions) 


> _input_ `::=` _number_
  

> _output_ `::=` `{` _output…_ `}`
  

| Output | Format | Description |
|:-------|:------:|:------------|
| `"reload"` | _boolean_ | array fully reloaded |
| `"removed"` | `$functions` `[]` | removed entries |
| `"updated"` | [`functionsData`](ast.md#functionsdata)  `[]` | updated entries |
| `"pending"` | _number_ | remaining entries to be fetched |


## kernel.ast.reloadFunctions (`GET`) {#reloadfunctions}

Force full reload for array [`functions`](#functions) 


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## kernel.ast.getInformationUpdate (`SIGNAL`) {#getinformationupdate}

Updated AST information


## kernel.ast.getInformation (`GET`) {#getinformation}

Get available information about markers. When no marker is given, returns all kinds of information (with empty `descr` field).


> _input_ `::=` [`marker`](ast.md#marker)  `?`
  

> _output_ `::=` `{` `"id"` `:` _string_ , `"label"` `:` _string_ , `"title"`
  `:` _string_ , `"descr"` `:` _string_ , `"text"` `:` [`text`](data.md#text)
   `}` `[]`
  

> _signals_
  

* `kernel.ast.getInformationUpdate`


## kernel.ast.getMarkerAt (`GET`) {#getmarkerat}

Returns the marker and function at a source file position, if any. Input: file path, line and column.


> _input_ `::=` `[` _string_ , _number_ , _number_ `]`
  

> _output_ `::=` `[` [`fct`](ast.md#fct)  `?` , [`marker`](ast.md#marker) 
  `?` `]`
  

## kernel.ast.getFiles (`GET`) {#getfiles}

Get the currently analyzed source file names


> _input_ `::=` _null_
  

> _output_ `::=` _string_ `[]`
  

## kernel.ast.setFiles (`SET`) {#setfiles}

Set the source file names to analyze.


> _input_ `::=` _string_ `[]`
  

> _output_ `::=` _null_
  

## kernel.ast.parseExpr (`GET`) {#parseexpr}

Parse a C expression and returns the associated marker


> _input_ `::=` `{` _input…_ `}`
  

> _output_ `::=` [`marker`](ast.md#marker) 
  

| Input | Format | Description |
|:------|:------:|:------------|
| `"stmt"` | [`marker`](ast.md#marker)  | Marker position from where to localize the term |
| `"term"` | _string_ | ACSL term to parse |


## kernel.ast.parseLval (`GET`) {#parselval}

Parse a C lvalue and returns the associated marker


> _input_ `::=` `{` _input…_ `}`
  

> _output_ `::=` [`marker`](ast.md#marker) 
  

| Input | Format | Description |
|:------|:------:|:------------|
| `"stmt"` | [`marker`](ast.md#marker)  | Marker position from where to localize the term |
| `"term"` | _string_ | ACSL term to parse |
