---
title: Kernel Services
author:
date: 2024-03-01
...

# Kernel Services {#kernel-services}

## kernel.services.getConfig (`GET`) {#getconfig}

Frama-C Kernel configuration


> _input_ `::=` _null_
  

> _output_ `::=` `{` _output…_ `}`
  

| Output | Format | Description |
|:-------|:------:|:------------|
| `"version"` | _string_ | Frama-C version |
| `"datadir"` | _string_ `[]` | Shared directory (FRAMAC_SHARE) |
| `"pluginpath"` | _string_ `[]` | Plugin directories (FRAMAC_PLUGIN) |


## kernel.services.load (`SET`) {#load}

Load a save file. Returns an error, if not successfull.


> _input_ `::=` _string_
  

> _output_ `::=` _string_ `?`
  

## kernel.services.save (`SET`) {#save}

Save the current session. Returns an error, if not successfull.


> _input_ `::=` _string_
  

> _output_ `::=` _string_ `?`
  

## kernel.services.logkind (`DATA`) {#logkind}

Log messages categories.


> [`logkind`](#logkind)  `::=` _tags…_
  

| Tags | Value | Description |
|:-----|:------|:------------|
| Error | `"ERROR"` | User Error |
| Warning | `"WARNING"` | User Warning |
| Feedback | `"FEEDBACK"` | Plugin Feedback |
| Result | `"RESULT"` | Plugin Result |
| Failure | `"FAILURE"` | Plugin Failure |
| Debug | `"DEBUG"` | Analyser Debug |


## kernel.services.logkindTags (`GET`) {#logkindtags}

Registered tags for the above type.


> _input_ `::=` _null_
  

> _output_ `::=` [`tag`](data.md#tag)  `[]`
  

## kernel.services.message (`ARRAY`) {#message}

Log messages


## kernel.services.signalMessage (`SIGNAL`) {#signalmessage}

Signal for array [`message`](#message) 


## kernel.services.messageData (`DATA`) {#messagedata}

Data for array rows [`message`](#message) 


> [`messageData`](#messagedata)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"key"` | `$message` | Entry identifier. |
| `"kind"` | [`logkind`](services.md#logkind)  | Message kind |
| `"plugin"` | _string_ | Emitter plugin |
| `"message"` | _string_ | Message text |
| `"category"` (opt.) | _string_ | Message category (only for debug or warning messages) |
| `"source"` (opt.) | [`source`](ast.md#source)  | Source file position |
| `"marker"` (opt.) | [`marker`](ast.md#marker)  | Marker at the message position (if any) |
| `"fct"` (opt.) | [`fct`](ast.md#fct)  | Function containing the message position (if any) |


## kernel.services.fetchMessage (`GET`) {#fetchmessage}

Data fetcher for array [`message`](#message) 


> _input_ `::=` _number_
  

> _output_ `::=` `{` _output…_ `}`
  

| Output | Format | Description |
|:-------|:------:|:------------|
| `"reload"` | _boolean_ | array fully reloaded |
| `"removed"` | `$message` `[]` | removed entries |
| `"updated"` | [`messageData`](services.md#messagedata)  `[]` | updated entries |
| `"pending"` | _number_ | remaining entries to be fetched |


## kernel.services.reloadMessage (`GET`) {#reloadmessage}

Force full reload for array [`message`](#message) 


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## kernel.services.log (`DATA`) {#log}

Message event record.


> [`log`](#log)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"kind"` | [`logkind`](services.md#logkind)  | Message kind |
| `"plugin"` | _string_ | Emitter plugin |
| `"message"` | _string_ | Message text |
| `"category"` (opt.) | _string_ | Message category (DEBUG or WARNING) |
| `"source"` (opt.) | [`source`](ast.md#source)  | Source file position |


## kernel.services.setLogs (`SET`) {#setlogs}

Turn logs monitoring on/off


> _input_ `::=` _boolean_
  

> _output_ `::=` _null_
  

## kernel.services.getLogs (`GET`) {#getlogs}

Flush the last emitted logs since last call (max 100)


> _input_ `::=` _null_
  

> _output_ `::=` [`log`](services.md#log)  `[]`
  