---
title: Presentation
author:
date: 2024-03-01
...

# Presentation

Version 28.1


## Protocols

* [Architecture](server.md) 
* [ZeroMQ Protocol](server_zmq.md) 
* [Unix Socket Protocol](server_socket.md) 
* [Batch Protocol](server_batch.md) 


## Kernel

* [Informations](kernel/data.md) 
* [Ast Services](kernel/ast.md) 
* [Property Services](kernel/properties.md) 
* [Project Management](kernel/project.md) 
* [Kernel Services](kernel/services.md) 


## Plugin Callgraph

* [Callgraph](plugins/callgraph/index.md) 


## Plugin Dive

* [Dive Services](plugins/dive/index.md) 


## Plugin Eva

* [Eva General Services](plugins/eva/general.md) 
* [Eva Values](plugins/eva/values.md) 


## Plugin Pivot

* [Pivot Table Services](plugins/pivot/general.md) 


## Plugin Studia

* [Studia](plugins/studia/studia.md) 


## Plugin Wp

* [WP Main Services](plugins/wp/index.md) 
* [WP Interactive Prover](plugins/wp/tip.md) 
* [WP Tactics](plugins/wp/tac.md) 


## Index

### Index of `kernel.ast`

* [kernel.ast.changed (`SIGNAL`)](kernel/ast.md#changed) 
* [kernel.ast.compute (`EXEC`)](kernel/ast.md#compute) 
* [kernel.ast.fct (`DATA`)](kernel/ast.md#fct) 
* [kernel.ast.fetchFunctions (`GET`)](kernel/ast.md#fetchfunctions) 
* [kernel.ast.fetchMarkerAttributes (`GET`)](kernel/ast.md#fetchmarkerattributes)
  
* [kernel.ast.functions (`ARRAY`)](kernel/ast.md#functions) 
* [kernel.ast.functionsData (`DATA`)](kernel/ast.md#functionsdata) 
* [kernel.ast.getFiles (`GET`)](kernel/ast.md#getfiles) 
* [kernel.ast.getFunctions (`GET`)](kernel/ast.md#getfunctions) 
* [kernel.ast.getInformation (`GET`)](kernel/ast.md#getinformation) 
* [kernel.ast.getInformationUpdate (`SIGNAL`)](kernel/ast.md#getinformationupdate)
  
* [kernel.ast.getMainFunction (`GET`)](kernel/ast.md#getmainfunction) 
* [kernel.ast.getMarkerAt (`GET`)](kernel/ast.md#getmarkerat) 
* [kernel.ast.location (`DATA`)](kernel/ast.md#location) 
* [kernel.ast.marker (`DATA`)](kernel/ast.md#marker) 
* [kernel.ast.markerAttributes (`ARRAY`)](kernel/ast.md#markerattributes) 
* [kernel.ast.markerAttributesData (`DATA`)](kernel/ast.md#markerattributesdata)
  
* [kernel.ast.parseExpr (`GET`)](kernel/ast.md#parseexpr) 
* [kernel.ast.parseLval (`GET`)](kernel/ast.md#parselval) 
* [kernel.ast.printFunction (`GET`)](kernel/ast.md#printfunction) 
* [kernel.ast.reloadFunctions (`GET`)](kernel/ast.md#reloadfunctions) 
* [kernel.ast.reloadMarkerAttributes (`GET`)](kernel/ast.md#reloadmarkerattributes)
  
* [kernel.ast.setFiles (`SET`)](kernel/ast.md#setfiles) 
* [kernel.ast.signalFunctions (`SIGNAL`)](kernel/ast.md#signalfunctions) 
* [kernel.ast.signalMarkerAttributes (`SIGNAL`)](kernel/ast.md#signalmarkerattributes)
  
* [kernel.ast.source (`DATA`)](kernel/ast.md#source) 


### Index of `kernel.data`

* [kernel.data.markdown (`DATA`)](kernel/data.md#markdown) 
* [kernel.data.tag (`DATA`)](kernel/data.md#tag) 
* [kernel.data.text (`DATA`)](kernel/data.md#text) 


### Index of `kernel.project`

* [kernel.project.create (`SET`)](kernel/project.md#create) 
* [kernel.project.getList (`GET`)](kernel/project.md#getlist) 
* [kernel.project.projectInfo (`DATA`)](kernel/project.md#projectinfo) 


### Index of `kernel.properties`

* [kernel.properties.alarms (`DATA`)](kernel/properties.md#alarms) 
* [kernel.properties.alarmsTags (`GET`)](kernel/properties.md#alarmstags) 
* [kernel.properties.fetchStatus (`GET`)](kernel/properties.md#fetchstatus) 
* [kernel.properties.propKind (`DATA`)](kernel/properties.md#propkind) 
* [kernel.properties.propKindTags (`GET`)](kernel/properties.md#propkindtags) 
* [kernel.properties.propStatus (`DATA`)](kernel/properties.md#propstatus) 
* [kernel.properties.propStatusTags (`GET`)](kernel/properties.md#propstatustags)
  
* [kernel.properties.reloadStatus (`GET`)](kernel/properties.md#reloadstatus) 
* [kernel.properties.signalStatus (`SIGNAL`)](kernel/properties.md#signalstatus)
  
* [kernel.properties.status (`ARRAY`)](kernel/properties.md#status) 
* [kernel.properties.statusData (`DATA`)](kernel/properties.md#statusdata) 


### Index of `kernel.services`

* [kernel.services.fetchMessage (`GET`)](kernel/services.md#fetchmessage) 
* [kernel.services.getConfig (`GET`)](kernel/services.md#getconfig) 
* [kernel.services.getLogs (`GET`)](kernel/services.md#getlogs) 
* [kernel.services.load (`SET`)](kernel/services.md#load) 
* [kernel.services.log (`DATA`)](kernel/services.md#log) 
* [kernel.services.logkind (`DATA`)](kernel/services.md#logkind) 
* [kernel.services.logkindTags (`GET`)](kernel/services.md#logkindtags) 
* [kernel.services.message (`ARRAY`)](kernel/services.md#message) 
* [kernel.services.messageData (`DATA`)](kernel/services.md#messagedata) 
* [kernel.services.reloadMessage (`GET`)](kernel/services.md#reloadmessage) 
* [kernel.services.save (`SET`)](kernel/services.md#save) 
* [kernel.services.setLogs (`SET`)](kernel/services.md#setlogs) 
* [kernel.services.signalMessage (`SIGNAL`)](kernel/services.md#signalmessage)
  


### Index of `plugins.callgraph`

* [plugins.callgraph.callgraph (`STATE`)](plugins/callgraph/index.md#callgraph)
  
* [plugins.callgraph.compute (`EXEC`)](plugins/callgraph/index.md#compute) 
* [plugins.callgraph.edge (`DATA`)](plugins/callgraph/index.md#edge) 
* [plugins.callgraph.edgeKind (`DATA`)](plugins/callgraph/index.md#edgekind) 
* [plugins.callgraph.edgeKindTags (`GET`)](plugins/callgraph/index.md#edgekindtags)
  
* [plugins.callgraph.getCallgraph (`GET`)](plugins/callgraph/index.md#getcallgraph)
  
* [plugins.callgraph.getIsComputed (`GET`)](plugins/callgraph/index.md#getiscomputed)
  
* [plugins.callgraph.graph (`DATA`)](plugins/callgraph/index.md#graph) 
* [plugins.callgraph.isComputed (`STATE`)](plugins/callgraph/index.md#iscomputed)
  
* [plugins.callgraph.signalCallgraph (`SIGNAL`)](plugins/callgraph/index.md#signalcallgraph)
  
* [plugins.callgraph.signalIsComputed (`SIGNAL`)](plugins/callgraph/index.md#signaliscomputed)
  
* [plugins.callgraph.vertex (`DATA`)](plugins/callgraph/index.md#vertex) 


### Index of `plugins.dive`

* [plugins.dive.add (`EXEC`)](plugins/dive/index.md#add) 
* [plugins.dive.callsite (`DATA`)](plugins/dive/index.md#callsite) 
* [plugins.dive.callstack (`DATA`)](plugins/dive/index.md#callstack) 
* [plugins.dive.clear (`EXEC`)](plugins/dive/index.md#clear) 
* [plugins.dive.dependency (`DATA`)](plugins/dive/index.md#dependency) 
* [plugins.dive.element (`DATA`)](plugins/dive/index.md#element) 
* [plugins.dive.exploration (`DATA`)](plugins/dive/index.md#exploration) 
* [plugins.dive.explorationTags (`GET`)](plugins/dive/index.md#explorationtags)
  
* [plugins.dive.explorationWindow (`DATA`)](plugins/dive/index.md#explorationwindow)
  
* [plugins.dive.explore (`EXEC`)](plugins/dive/index.md#explore) 
* [plugins.dive.fetchGraph (`GET`)](plugins/dive/index.md#fetchgraph) 
* [plugins.dive.graph (`ARRAY`)](plugins/dive/index.md#graph) 
* [plugins.dive.graphData (`DATA`)](plugins/dive/index.md#graphdata) 
* [plugins.dive.hide (`EXEC`)](plugins/dive/index.md#hide) 
* [plugins.dive.node (`DATA`)](plugins/dive/index.md#node) 
* [plugins.dive.nodeId (`DATA`)](plugins/dive/index.md#nodeid) 
* [plugins.dive.nodeKind (`DATA`)](plugins/dive/index.md#nodekind) 
* [plugins.dive.nodeKindTags (`GET`)](plugins/dive/index.md#nodekindtags) 
* [plugins.dive.nodeLocality (`DATA`)](plugins/dive/index.md#nodelocality) 
* [plugins.dive.nodeRange (`DATA`)](plugins/dive/index.md#noderange) 
* [plugins.dive.nodeSpecialRange (`DATA`)](plugins/dive/index.md#nodespecialrange)
  
* [plugins.dive.nodeSpecialRangeTags (`GET`)](plugins/dive/index.md#nodespecialrangetags)
  
* [plugins.dive.range (`DATA`)](plugins/dive/index.md#range) 
* [plugins.dive.reloadGraph (`GET`)](plugins/dive/index.md#reloadgraph) 
* [plugins.dive.show (`EXEC`)](plugins/dive/index.md#show) 
* [plugins.dive.signalGraph (`SIGNAL`)](plugins/dive/index.md#signalgraph) 
* [plugins.dive.taint (`DATA`)](plugins/dive/index.md#taint) 
* [plugins.dive.taintTags (`GET`)](plugins/dive/index.md#tainttags) 
* [plugins.dive.window (`SET`)](plugins/dive/index.md#window) 


### Index of `plugins.eva.general`

* [plugins.eva.general.CallSite (`DATA`)](plugins/eva/general.md#callsite) 
* [plugins.eva.general.LvalueTaints (`DATA`)](plugins/eva/general.md#lvaluetaints)
  
* [plugins.eva.general.alarmCategory (`DATA`)](plugins/eva/general.md#alarmcategory)
  
* [plugins.eva.general.alarmCategoryTags (`GET`)](plugins/eva/general.md#alarmcategorytags)
  
* [plugins.eva.general.alarmEntry (`DATA`)](plugins/eva/general.md#alarmentry)
  
* [plugins.eva.general.computationState (`STATE`)](plugins/eva/general.md#computationstate)
  
* [plugins.eva.general.computationStateType (`DATA`)](plugins/eva/general.md#computationstatetype)
  
* [plugins.eva.general.deadCode (`DATA`)](plugins/eva/general.md#deadcode) 
* [plugins.eva.general.fetchFunctionStats (`GET`)](plugins/eva/general.md#fetchfunctionstats)
  
* [plugins.eva.general.fetchFunctions (`GET`)](plugins/eva/general.md#fetchfunctions)
  
* [plugins.eva.general.fetchProperties (`GET`)](plugins/eva/general.md#fetchproperties)
  
* [plugins.eva.general.functionStats (`ARRAY`)](plugins/eva/general.md#functionstats)
  
* [plugins.eva.general.functionStatsData (`DATA`)](plugins/eva/general.md#functionstatsdata)
  
* [plugins.eva.general.functions (`ARRAY`)](plugins/eva/general.md#functions) 
* [plugins.eva.general.functionsData (`DATA`)](plugins/eva/general.md#functionsdata)
  
* [plugins.eva.general.getCallees (`GET`)](plugins/eva/general.md#getcallees) 
* [plugins.eva.general.getCallers (`GET`)](plugins/eva/general.md#getcallers) 
* [plugins.eva.general.getComputationState (`GET`)](plugins/eva/general.md#getcomputationstate)
  
* [plugins.eva.general.getDeadCode (`GET`)](plugins/eva/general.md#getdeadcode)
  
* [plugins.eva.general.getProgramStats (`GET`)](plugins/eva/general.md#getprogramstats)
  
* [plugins.eva.general.getStates (`GET`)](plugins/eva/general.md#getstates) 
* [plugins.eva.general.programStats (`STATE`)](plugins/eva/general.md#programstats)
  
* [plugins.eva.general.programStatsType (`DATA`)](plugins/eva/general.md#programstatstype)
  
* [plugins.eva.general.properties (`ARRAY`)](plugins/eva/general.md#properties)
  
* [plugins.eva.general.propertiesData (`DATA`)](plugins/eva/general.md#propertiesdata)
  
* [plugins.eva.general.reloadFunctionStats (`GET`)](plugins/eva/general.md#reloadfunctionstats)
  
* [plugins.eva.general.reloadFunctions (`GET`)](plugins/eva/general.md#reloadfunctions)
  
* [plugins.eva.general.reloadProperties (`GET`)](plugins/eva/general.md#reloadproperties)
  
* [plugins.eva.general.signalComputationState (`SIGNAL`)](plugins/eva/general.md#signalcomputationstate)
  
* [plugins.eva.general.signalFunctionStats (`SIGNAL`)](plugins/eva/general.md#signalfunctionstats)
  
* [plugins.eva.general.signalFunctions (`SIGNAL`)](plugins/eva/general.md#signalfunctions)
  
* [plugins.eva.general.signalProgramStats (`SIGNAL`)](plugins/eva/general.md#signalprogramstats)
  
* [plugins.eva.general.signalProperties (`SIGNAL`)](plugins/eva/general.md#signalproperties)
  
* [plugins.eva.general.statusesEntry (`DATA`)](plugins/eva/general.md#statusesentry)
  
* [plugins.eva.general.taintStatus (`DATA`)](plugins/eva/general.md#taintstatus)
  
* [plugins.eva.general.taintStatusTags (`GET`)](plugins/eva/general.md#taintstatustags)
  
* [plugins.eva.general.taintedLvalues (`GET`)](plugins/eva/general.md#taintedlvalues)
  


### Index of `plugins.eva.values`

* [plugins.eva.values.callstack (`DATA`)](plugins/eva/values.md#callstack) 
* [plugins.eva.values.changed (`SIGNAL`)](plugins/eva/values.md#changed) 
* [plugins.eva.values.evaluation (`DATA`)](plugins/eva/values.md#evaluation) 
* [plugins.eva.values.getCallstackInfo (`GET`)](plugins/eva/values.md#getcallstackinfo)
  
* [plugins.eva.values.getCallstacks (`GET`)](plugins/eva/values.md#getcallstacks)
  
* [plugins.eva.values.getProbeInfo (`GET`)](plugins/eva/values.md#getprobeinfo)
  
* [plugins.eva.values.getStmtInfo (`GET`)](plugins/eva/values.md#getstmtinfo) 
* [plugins.eva.values.getValues (`GET`)](plugins/eva/values.md#getvalues) 


### Index of `plugins.pivot.general`

* [plugins.pivot.general.compute (`EXEC`)](plugins/pivot/general.md#compute) 
* [plugins.pivot.general.getPivotState (`GET`)](plugins/pivot/general.md#getpivotstate)
  
* [plugins.pivot.general.pivotState (`STATE`)](plugins/pivot/general.md#pivotstate)
  
* [plugins.pivot.general.signalPivotState (`SIGNAL`)](plugins/pivot/general.md#signalpivotstate)
  
* [plugins.pivot.general.tableStateType (`DATA`)](plugins/pivot/general.md#tablestatetype)
  


### Index of `plugins.studia.studia`

* [plugins.studia.studia.effects (`DATA`)](plugins/studia/studia.md#effects) 
* [plugins.studia.studia.getReadsLval (`GET`)](plugins/studia/studia.md#getreadslval)
  
* [plugins.studia.studia.getWritesLval (`GET`)](plugins/studia/studia.md#getwriteslval)
  


### Index of `plugins.wp`

* [plugins.wp.cancelProofTasks (`SET`)](plugins/wp/index.md#cancelprooftasks) 
* [plugins.wp.fetchGoals (`GET`)](plugins/wp/index.md#fetchgoals) 
* [plugins.wp.getAvailableProvers (`GET`)](plugins/wp/index.md#getavailableprovers)
  
* [plugins.wp.getScheduledTasks (`GET`)](plugins/wp/index.md#getscheduledtasks)
  
* [plugins.wp.goal (`DATA`)](plugins/wp/index.md#goal) 
* [plugins.wp.goals (`ARRAY`)](plugins/wp/index.md#goals) 
* [plugins.wp.goalsData (`DATA`)](plugins/wp/index.md#goalsdata) 
* [plugins.wp.prover (`DATA`)](plugins/wp/index.md#prover) 
* [plugins.wp.reloadGoals (`GET`)](plugins/wp/index.md#reloadgoals) 
* [plugins.wp.result (`DATA`)](plugins/wp/index.md#result) 
* [plugins.wp.serverActivity (`SIGNAL`)](plugins/wp/index.md#serveractivity) 
* [plugins.wp.signalGoals (`SIGNAL`)](plugins/wp/index.md#signalgoals) 
* [plugins.wp.stats (`DATA`)](plugins/wp/index.md#stats) 
* [plugins.wp.status (`DATA`)](plugins/wp/index.md#status) 


### Index of `plugins.wp.tac`

* [plugins.wp.tac.applyTactic (`EXEC`)](plugins/wp/tac.md#applytactic) 
* [plugins.wp.tac.configureTactics (`EXEC`)](plugins/wp/tac.md#configuretactics)
  
* [plugins.wp.tac.fetchTactical (`GET`)](plugins/wp/tac.md#fetchtactical) 
* [plugins.wp.tac.kind (`DATA`)](plugins/wp/tac.md#kind) 
* [plugins.wp.tac.parameter (`DATA`)](plugins/wp/tac.md#parameter) 
* [plugins.wp.tac.reloadTactical (`GET`)](plugins/wp/tac.md#reloadtactical) 
* [plugins.wp.tac.setParameter (`EXEC`)](plugins/wp/tac.md#setparameter) 
* [plugins.wp.tac.signalTactical (`SIGNAL`)](plugins/wp/tac.md#signaltactical)
  
* [plugins.wp.tac.status (`DATA`)](plugins/wp/tac.md#status) 
* [plugins.wp.tac.tactical (`ARRAY`)](plugins/wp/tac.md#tactical) 
* [plugins.wp.tac.tacticalData (`DATA`)](plugins/wp/tac.md#tacticaldata) 
* [plugins.wp.tac.value (`DATA`)](plugins/wp/tac.md#value) 


### Index of `plugins.wp.tip`

* [plugins.wp.tip.clearSelection (`SET`)](plugins/wp/tip.md#clearselection) 
* [plugins.wp.tip.getNodeInfos (`GET`)](plugins/wp/tip.md#getnodeinfos) 
* [plugins.wp.tip.getProofState (`GET`)](plugins/wp/tip.md#getproofstate) 
* [plugins.wp.tip.goForward (`SET`)](plugins/wp/tip.md#goforward) 
* [plugins.wp.tip.goToIndex (`SET`)](plugins/wp/tip.md#gotoindex) 
* [plugins.wp.tip.goToNode (`SET`)](plugins/wp/tip.md#gotonode) 
* [plugins.wp.tip.goToRoot (`SET`)](plugins/wp/tip.md#gotoroot) 
* [plugins.wp.tip.iformat (`DATA`)](plugins/wp/tip.md#iformat) 
* [plugins.wp.tip.printSequent (`EXEC`)](plugins/wp/tip.md#printsequent) 
* [plugins.wp.tip.printStatus (`SIGNAL`)](plugins/wp/tip.md#printstatus) 
* [plugins.wp.tip.proofStatus (`SIGNAL`)](plugins/wp/tip.md#proofstatus) 
* [plugins.wp.tip.removeNode (`SET`)](plugins/wp/tip.md#removenode) 
* [plugins.wp.tip.rformat (`DATA`)](plugins/wp/tip.md#rformat) 
* [plugins.wp.tip.setSelection (`SET`)](plugins/wp/tip.md#setselection) 
